==> knative-client-4.12.0-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/GitLabSourceOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.DoneableGitLabSource;
import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabSource;
import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabSourceList;
import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.DoneableGitLabSource;

import java.util.Map;
import java.util.TreeMap;


public class GitLabSourceOperationsImpl extends HasMetadataOperation<GitLabSource, GitLabSourceList, DoneableGitLabSource, Resource<GitLabSource, DoneableGitLabSource>> {

  public GitLabSourceOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public GitLabSourceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("sources.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("gitlabsources"));
    this.type = GitLabSource.class;
    this.listType = GitLabSourceList.class;
    this.doneableType = DoneableGitLabSource.class;
  }

  public GitLabSourceOperationsImpl newInstance(OperationContext context) {
    return new GitLabSourceOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> knative-client-5.3.2-sources.jar: io/fabric8/knative/client/eventing/v1alpha1/internal/GitLabSourceOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1alpha1.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabSource;
import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabSourceBuilder;
import io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabSourceList;

import java.util.Map;
import java.util.TreeMap;


public class GitLabSourceOperationsImpl extends HasMetadataOperation<GitLabSource, GitLabSourceList, Resource<GitLabSource>> {

  public GitLabSourceOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public GitLabSourceOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("sources.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("gitlabsources"));
    this.type = GitLabSource.class;
    this.listType = GitLabSourceList.class;
  }

  public GitLabSourceOperationsImpl newInstance(OperationContext context) {
    return new GitLabSourceOperationsImpl(context);
  }

  @Override
  public GitLabSource edit(Visitor... visitors) {
    return patch(new GitLabSourceBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
